# Seismometerneigungssignalanalysator (SeiNei)
Seismometer Tilt Signal Analyzer

A tool to extract long-period ground tilt signals from broadband seismometer data.

SeiNei is on [PyPi](https://pypi.org/project/seinei/) and can be installed with `pip`:  
`pip install seinei`  
   
For usage instructions see [SeiNei's documentation](https://github.com/mchristoffersen/SeiNei/wiki).
